@@ -27,7 +27,7 @@
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
-#endif /* HAVE_CONFIG_H */
+#endif /* defined(HAVE_CONFIG_H) */
 
 #define MUNIT_ENABLE_ASSERT_ALIASES
 
@@ -38,4 +38,4 @@ extern const MunitSuite pv_suite;
 munit_void_test_decl(test_ngtcp2_pv_add_entry);
 munit_void_test_decl(test_ngtcp2_pv_validate);
 
-#endif /* NGTCP2_PV_TEST_H */
+#endif /* !defined(NGTCP2_PV_TEST_H) */
